@@ -546,7 +546,9 @@ typedef struct
 	GtkWidget *window;
 	GtkWidget *notebook;
 
+#ifndef USE_CLOSE_AND_CANCEL_BUTTONS
 	GtkWidget *closebutton;
+#endif /* !USE_CLOSE_AND_CANCEL_BUTTONS */
 } CertMgrDialog;
 
 /* If a certificate manager window is open, this will point to it.
@@ -628,9 +630,11 @@ pidgin_certmgr_show(void)
 			   0);
 	gtk_widget_show(dlg->notebook);
 
+#ifdef USE_CLOSE_AND_CANCEL_BUTTONS
 	/* Close button */
 	dlg->closebutton = pidgin_dialog_add_button(GTK_DIALOG(win), GTK_STOCK_CLOSE,
 			G_CALLBACK(certmgr_close_cb), dlg);
+#endif /* USE_CLOSE_AND_CANCEL_BUTTONS */
 
 	/* Add the defined certificate managers */
 	/* TODO: Find a way of determining whether each is shown or not */
